/*****************************************************************************
 *                                                                           *
 *     Header for messages                                                   *
 *     Version 1.1                        Author      :    Henry Koplien     *
 *                                        Create date :    19.11.98          *
 *                                        Last edit   :    29.11.98          *
 *****************************************************************************/
/**
  *  This class handles the output to tty's.
  *  The benefit of this class is an centralized object where the whole
  *  I/O of tty's is handled. This class is used for error handling too.
  *  If there are any redirections of output, here is the right place.
  *  In this particular case all the stuff is logged in the syslog under 
  *  {\em upsd}. In the version 1.1 all the signal handler messages where
  *  moved to this object, so all syslog activities can be found here.
  *
  *  @author  Henry Koplien
  *  @version 1.1 (first release 19. November 1998, last edit 29. November 1998)
  */
class sys_message: public mail, public memory {

public: 
             
  /**
    *  The function handles messages.
    *  All the messages which should go to the tty are processed with this
    *  method. The message is logged in the syslog with a preceding
    *  {\em UPS-Information:}.
    *
    *  @param  text is the message to be logged
    */
  void             message               (char *text);
  /**
    *  The function handles warnings.
    *  All the warnings which should go to the tty are processed with this
    *  method. The message is logged in the syslog with a preceding
    *  {\em UPS-Warning:}.
    *
    *  @param  text is the warning to be logged
    */
  void             warning               (char *text);
  /**
    *  The function handles errors.
    *  All the errors which should go to the tty are processed with this
    *  method. The message given out is declared through {\em id\_num}. For
    *  further information see {\bf global.hpp} for the different kind of
    *  errors. Most errors lead to termination with exit -1.
    *
    *  @param  id_num defines the type of message to be logged\\
    *          Which id's are supported is defined in {\bf global.hpp}.
    *          There you will find the complete set of errors, used for this
    *          and other methods.
    *  @param  text is additional information of the caller (e.g. which class
    *          and method found the error) 
    */
  void             error                 (error_set id_num, char *text);

public:

  /**
    *  The constructor.
    *  Used to set up initial data and open the syslog file for {\em upsd}
    *  entries. Enables everything for logging, except {\bf LOG\_DEBUG}.
    */
                   sys_message           (void);
  /**
    *  The destructor.
    *  Release/Close the log file for {\em upsd}.
    */
                   ~sys_message          (void);
};
